@@ -15,7 +15,7 @@ documentation: http://www.crummy.com/software/BeautifulSoup/bs4/doc/
 """
 
 __author__ = "Leonard Richardson (leonardr@segfault.org)"
-__version__ = "4.13.2"
+__version__ = "4.14.1"
 __copyright__ = "Copyright (c) 2004-2025 Leonard Richardson"
 # Use of this source code is governed by the MIT license.
 __license__ = "MIT"
@@ -51,6 +51,7 @@ __all__ = [
 ]
 
 from collections import Counter
+import io
 import sys
 import warnings
 
@@ -100,6 +101,7 @@ from typing import (
     Iterator,
     List,
     Sequence,
+    Sized,
     Optional,
     Type,
     Union,
@@ -349,7 +351,7 @@ class BeautifulSoup(Tag):
         original_builder = builder
         original_features = features
 
-        builder_class: Type[TreeBuilder]
+        builder_class: Optional[Type[TreeBuilder]] = None
         if isinstance(builder, type):
             # A builder class was passed in; it needs to be instantiated.
             builder_class = builder
@@ -372,6 +374,7 @@ class BeautifulSoup(Tag):
         # builder, or we have a builder_class that we can instantiate
         # with the remaining **kwargs.
         if builder is None:
+            assert builder_class is not None
             builder = builder_class(**kwargs)
             if (
                 not original_builder
@@ -437,12 +440,12 @@ class BeautifulSoup(Tag):
         self.parse_only = parse_only
 
         if hasattr(markup, "read"):  # It's a file-type object.
-            markup = markup.read()
+            markup = cast(io.IOBase, markup).read()
         elif not isinstance(markup, (bytes, str)) and not hasattr(markup, "__len__"):
             raise TypeError(
                 f"Incoming markup is of an invalid type: {markup!r}. Markup must be a string, a bytestring, or an open filehandle."
             )
-        elif len(markup) <= 256 and (
+        elif isinstance(markup, Sized) and len(markup) <= 256 and (
             (isinstance(markup, bytes) and b"<" not in markup and b"\n" not in markup)
             or (isinstance(markup, str) and "<" not in markup and "\n" not in markup)
         ):
@@ -1118,6 +1121,7 @@ class BeautifulSoup(Tag):
         # argument to this method (or a keyword argument with the old
         # name), we can handle it and put out a DeprecationWarning.
         warning: Optional[str] = None
+        pretty_print: Optional[bool] = None
         if isinstance(indent_level, bool):
             if indent_level is True:
                 indent_level = 0
